#[repr(i32)]pub enum GraphAnalyticsAlgorithm {
GraphAnalyticsPagerank = 0,
GraphAnalyticsWcc = 1,
GraphAnalyticsDegreeCentrality = 2,
GraphAnalyticsLabelPropagation = 3,
}Variants
GraphAnalyticsPagerank = 0
GraphAnalyticsWcc = 1
weakly connected components
GraphAnalyticsDegreeCentrality = 2
GraphAnalyticsLabelPropagation = 3
deferred (community detection)
Implementations
Sourceimpl GraphAnalyticsAlgorithm
impl GraphAnalyticsAlgorithm
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of GraphAnalyticsAlgorithm.
Sourcepub fn from_i32(value: i32) -> Option<GraphAnalyticsAlgorithm>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<GraphAnalyticsAlgorithm>
Use the TryFrom<i32> implementation instead
Converts an i32 to a GraphAnalyticsAlgorithm, or None if value is not a valid variant.
Sourceimpl GraphAnalyticsAlgorithm
impl GraphAnalyticsAlgorithm
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.