#[repr(i32)]pub enum GraphPathAlgorithm {
GraphPathDijkstra = 0,
GraphPathAstar = 1,
}Expand description
Pathfinding algorithm. A* currently shares Dijkstra’s relaxation (no spatial heuristic is available for arbitrary node ids), so it behaves as Dijkstra but is accepted for forward compatibility.
Variants
Implementations
Sourceimpl GraphPathAlgorithm
impl GraphPathAlgorithm
Sourcepub fn from_i32(value: i32) -> Option<GraphPathAlgorithm>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<GraphPathAlgorithm>
Use the TryFrom<i32> implementation instead
Converts an i32 to a GraphPathAlgorithm, or None if value is not a valid variant.
Sourceimpl GraphPathAlgorithm
impl GraphPathAlgorithm
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.