#[repr(i32)]pub enum PayloadFieldKind {
PayloadFieldEquality = 0,
PayloadFieldRange = 1,
}Expand description
The kind of secondary index built for a payload field.
Variants
PayloadFieldEquality = 0
keyword/bool/exact int/str -> roaring bitmap
PayloadFieldRange = 1
numeric -> sorted (value,id)
Implementations
Sourceimpl PayloadFieldKind
impl PayloadFieldKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.