#[repr(i32)]pub enum ResolveLockOutcome {
ResolveLockClear = 0,
ResolveLockRolledForward = 1,
ResolveLockPending = 2,
}Expand description
The resolution outcome (mirrors reactive::ResolveOutcome).
Variants
ResolveLockClear = 0
no blocking lock (or cleaned): read normally
ResolveLockRolledForward = 1
committed secondary rolled forward
ResolveLockPending = 2
live lock, decision pending: back off + retry
Implementations
Sourceimpl ResolveLockOutcome
impl ResolveLockOutcome
Sourcepub fn from_i32(value: i32) -> Option<ResolveLockOutcome>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ResolveLockOutcome>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ResolveLockOutcome, or None if value is not a valid variant.
Sourceimpl ResolveLockOutcome
impl ResolveLockOutcome
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.