#[repr(i32)]pub enum ScoreFusion {
Rrf = 0,
Linear = 1,
}Expand description
How the three component scores are fused into one scalar.
Variants
Rrf = 0
rank-based reciprocal-rank fusion (robust across score scales)
Linear = 1
weighted linear blend of normalized component scores
Implementations
Sourceimpl ScoreFusion
impl ScoreFusion
Sourceimpl ScoreFusion
impl ScoreFusion
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.