#[repr(i32)]pub enum SetExpectation {
IfAbsent = 0,
IfPresent = 1,
IfValueEquals = 2,
}Expand description
Predicate for an atomic conditional set (ConditionalSet).
Variants
IfAbsent = 0
NX: apply the write only if the key has no live value
IfPresent = 1
XX: apply the write only if the key already has a live value
IfValueEquals = 2
CAS: apply only if the live value matches expected_value
Implementations
Sourceimpl SetExpectation
impl SetExpectation
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.