#[repr(i32)]pub enum VectorFilterOp {
Eq = 0,
Ne = 1,
Lt = 2,
Lte = 3,
Gt = 4,
Gte = 5,
}Variants
Eq = 0
field == value
Ne = 1
field != value
Lt = 2
field < value (numeric)
Lte = 3
field <= value (numeric)
Gt = 4
field > value (numeric)
Gte = 5
field >= value (numeric)
Implementations
Sourceimpl VectorFilterOp
impl VectorFilterOp
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.