#[repr(i32)]pub enum VectorIndexType {
VectorIndexHnsw = 0,
VectorIndexPqHnsw = 1,
VectorIndexSqHnsw = 2,
VectorIndexIvfPq = 3,
VectorIndexIvfSq = 4,
VectorIndexSpfresh = 5,
VectorIndexSpfreshLsm = 6,
VectorIndexDiskann = 7,
VectorIndexMultivector = 8,
}Expand description
The type of vector index — determines quantization / structure.
Variants
VectorIndexHnsw = 0
Plain HNSW (exact distances)
VectorIndexPqHnsw = 1
PQ-accelerated HNSW
VectorIndexSqHnsw = 2
SQ8-accelerated HNSW
VectorIndexIvfPq = 3
IVF with PQ fine quantization
VectorIndexIvfSq = 4
IVF with SQ8 fine quantization
VectorIndexSpfresh = 5
SPFresh IVF-PQ with LIRE incremental rebalancing
VectorIndexSpfreshLsm = 6
DEPRECATED/RETIRED: route to a graph SpFresh index; create returns FailedPrecondition
VectorIndexDiskann = 7
DiskANN/Vamana SSD-resident graph (PQ in RAM, vectors+graph on SSD)
VectorIndexMultivector = 8
ColBERT-style late-interaction multi-vector index
Implementations
Sourceimpl VectorIndexType
impl VectorIndexType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.