pub struct AgentResolveLockResponse {
pub outcome: i32,
pub commit_ts: u64,
}Fields
outcome: i32commit_ts: u64On ROLLED_FORWARD, the HLC commit_ts the version became visible at.
Implementations
Sourceimpl AgentResolveLockResponse
impl AgentResolveLockResponse
Sourcepub fn outcome(&self) -> ResolveLockOutcome
pub fn outcome(&self) -> ResolveLockOutcome
Returns the enum value of outcome, or the default if the field is set to an invalid enum value.
Sourcepub fn set_outcome(&mut self, value: ResolveLockOutcome)
pub fn set_outcome(&mut self, value: ResolveLockOutcome)
Sets outcome to the provided enum value.