pub struct AgentStateEdgeProto {
pub anchor: u64,
pub src: u64,
pub dst: u64,
pub edge_type: String,
pub valid_from: u64,
pub valid_to: u64,
pub tx_from: u64,
pub tx_to: u64,
pub author_agent_id: String,
pub props: Vec<u8>,
}Fields
anchor: u64Which requested anchor this edge belongs to. Explicit rather than inferred from src/dst: under “both” an edge can attach to an anchor from either end, and a self-edge attaches from both.
src: u64dst: u64edge_type: Stringvalid_from: u64valid_to: u640 = permanently valid
tx_from: u64tx_to: u640 = still believed
props: Vec<u8>Trait Implementations
Sourceimpl Clone for AgentStateEdgeProto
impl Clone for AgentStateEdgeProto
Sourcefn clone(&self) -> AgentStateEdgeProto
fn clone(&self) -> AgentStateEdgeProto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentStateEdgeProto
impl Debug for AgentStateEdgeProto
Sourceimpl Default for AgentStateEdgeProto
impl Default for AgentStateEdgeProto
Sourceimpl Message for AgentStateEdgeProto
impl Message for AgentStateEdgeProto
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AgentStateEdgeProto
impl PartialEq for AgentStateEdgeProto
impl StructuralPartialEq for AgentStateEdgeProto