pub struct ConditionalSetRequest {
pub cf: u32,
pub key: Vec<u8>,
pub value: Vec<u8>,
pub expect: i32,
pub shard_id: u64,
pub shard_epoch: u64,
pub expected_value: Vec<u8>,
}Fields
cf: u32key: Vec<u8>value: Vec<u8>expect: i32shard_id: u64shard_epoch: u64expected_value: Vec<u8>Implementations
Sourceimpl ConditionalSetRequest
impl ConditionalSetRequest
Sourcepub fn expect(&self) -> SetExpectation
pub fn expect(&self) -> SetExpectation
Returns the enum value of expect, or the default if the field is set to an invalid enum value.
Sourcepub fn set_expect(&mut self, value: SetExpectation)
pub fn set_expect(&mut self, value: SetExpectation)
Sets expect to the provided enum value.