pub struct FusionSpecProto {
pub mode: i32,
pub rrf_k: f32,
pub dense_weight: f32,
pub sparse_weight: f32,
pub alpha: f32,
}Fields
mode: i32rrf_k: f32RRF k constant (default 60 when 0)
dense_weight: f32RRF: dense list weight (default 1)
sparse_weight: f32RRF: sparse list weight (default 1)
alpha: f32Weighted: alpha*dense + (1-alpha)*sparse
Implementations
Sourceimpl FusionSpecProto
impl FusionSpecProto
Sourcepub fn mode(&self) -> FusionMode
pub fn mode(&self) -> FusionMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: FusionMode)
pub fn set_mode(&mut self, value: FusionMode)
Sets mode to the provided enum value.