pub struct GraphAddEdgeRequest {
pub graph_name: String,
pub src: u64,
pub dst: u64,
pub edge_type: String,
pub valid_from: u64,
pub valid_to: u64,
pub properties: Vec<u8>,
pub tx_from: u64,
pub tx_to: u64,
}Fields
graph_name: Stringsrc: u64dst: u64edge_type: Stringvalid_from: u64timestamp (ms)
valid_to: u640 = no expiry
properties: Vec<u8>tx_from: u64Bitemporal transaction-time (recorded-at), ms. tx_from = when this edge revision became believed (0 = default to the write time at the data node). tx_to = when it was superseded/corrected (0 = still believed).
tx_to: u64Trait Implementations
Sourceimpl Clone for GraphAddEdgeRequest
impl Clone for GraphAddEdgeRequest
Sourcefn clone(&self) -> GraphAddEdgeRequest
fn clone(&self) -> GraphAddEdgeRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GraphAddEdgeRequest
impl Debug for GraphAddEdgeRequest
Sourceimpl Default for GraphAddEdgeRequest
impl Default for GraphAddEdgeRequest
Sourceimpl Message for GraphAddEdgeRequest
impl Message for GraphAddEdgeRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GraphAddEdgeRequest
impl PartialEq for GraphAddEdgeRequest
impl StructuralPartialEq for GraphAddEdgeRequest