pub struct KnowledgeChangeProto {
pub change_type: i32,
pub before: Option<TeamTemporalEdgeProto>,
pub after: Option<TeamTemporalEdgeProto>,
}Expand description
One classified change in the team’s knowledge between two transaction instants, with the before/after edge revisions where applicable.
Fields
change_type: i32before: Option<TeamTemporalEdgeProto>present for RETRACTED, REVALUED
after: Option<TeamTemporalEdgeProto>present for ASSERTED, REVALUED
Implementations
Sourceimpl KnowledgeChangeProto
impl KnowledgeChangeProto
Sourcepub fn change_type(&self) -> ChangeType
pub fn change_type(&self) -> ChangeType
Returns the enum value of change_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_change_type(&mut self, value: ChangeType)
pub fn set_change_type(&mut self, value: ChangeType)
Sets change_type to the provided enum value.