pub struct VectorFilterCondition {
pub field: String,
pub op: i32,
pub value: Option<VectorFilterValue>,
}Fields
field: Stringop: i32value: Option<VectorFilterValue>Implementations
Sourceimpl VectorFilterCondition
impl VectorFilterCondition
Sourcepub fn op(&self) -> VectorFilterOp
pub fn op(&self) -> VectorFilterOp
Returns the enum value of op, or the default if the field is set to an invalid enum value.
Sourcepub fn set_op(&mut self, value: VectorFilterOp)
pub fn set_op(&mut self, value: VectorFilterOp)
Sets op to the provided enum value.