pub struct VectorIndexStatsProto {
pub index_name: String,
pub index_type: String,
pub dim: u32,
pub num_vectors: u64,
pub promoted_tenants: u32,
pub fallback_vectors: u64,
}Fields
index_name: Stringindex_type: String“HNSW”, “PQ_HNSW”, “SQ_HNSW”, “IVF_PQ”, “IVF_SQ”, “SPFresh”, “TENANTED”
dim: u32num_vectors: u64promoted_tenants: u32Tenant tiering (epic #1428, Phase 2). Only meaningful for “TENANTED”
indices; 0 for every other index type. promoted_tenants is the number of
tenants that have graduated to a dedicated O(tenant) sub-graph, and
fallback_vectors is how many vectors remain in the shared small-tenant
fallback graph — so a client can observe the O(tenant) tiering via stats.
fallback_vectors: u64Trait Implementations
Sourceimpl Clone for VectorIndexStatsProto
impl Clone for VectorIndexStatsProto
Sourcefn clone(&self) -> VectorIndexStatsProto
fn clone(&self) -> VectorIndexStatsProto
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VectorIndexStatsProto
impl Debug for VectorIndexStatsProto
Sourceimpl Default for VectorIndexStatsProto
impl Default for VectorIndexStatsProto
Sourceimpl Message for VectorIndexStatsProto
impl Message for VectorIndexStatsProto
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for VectorIndexStatsProto
impl PartialEq for VectorIndexStatsProto
impl StructuralPartialEq for VectorIndexStatsProto